@@ -24,27 +24,6 @@ spocc_capwords <- function(s, strict = FALSE, onlyfirst = FALSE) {
     }
 }
 
-#' Coerces data.frame columns to the specified classes
-#'
-#' @param d A data.frame.
-#' @param colClasses A vector of column attributes, one of:
-#'    numeric, factor, character, etc.
-#' @examples  \dontrun{
-#' dat <- data.frame(xvar = seq(1:10), yvar = rep(c('a','b'),5)) # make a data.frame
-#' str(dat)
-#' str(spocc_colClasses(dat, c('factor','factor')))
-#' }
-#' @export
-#' @keywords internal
-spocc_colClasses <- function(d, colClasses) {
-    colClasses <- rep(colClasses, len = length(d))
-    d[] <- lapply(seq_along(d), function(i) switch(colClasses[i], numeric = as.numeric(d[[i]]),
-        character = as.character(d[[i]]), Date = as.Date(d[[i]], origin = "1970-01-01"),
-        POSIXct = as.POSIXct(d[[i]], origin = "1970-01-01"), factor = as.factor(d[[i]]),
-        as(d[[i]], colClasses[i])))
-    d
-}
-
 sc <- function(l) Filter(Negate(is.null), l)
 
 pluck <- function(x, name, type) {
@@ -94,7 +73,7 @@ check_integer <- function(x) {
 is_numeric <- function(x) {
   if (!is.null(x)) {
     tt <- tryCatch(as.numeric(x), error = function(e) e, warning = function(w) w)
-    if (is(tt, 'warning') || is(tt, 'error') || typeof(x) == "list") {
+    if (inherits(tt, 'warning') || inherits(tt, 'error') || typeof(x) == "list") {
       FALSE
     } else {
       check_integer(x)
